@@ -55,7 +55,7 @@ class Processor:
             total_consumed = int(time.time() - self.start_time)
             time_consumed = int(time.time() - self.time_anchor[1])
             data_consumed = self.time_anchor[0] - qsize
-            if time_consumed > 0:
+            if time_consumed != 0 and data_consumed != 0:
                 speed = data_consumed / time_consumed
                 eta = int(qsize / speed)
                 if time_consumed >= 60:
