@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+
 """Tornado Blueprint蓝图的实现。"""
 import asyncio
 import collections
 import inspect
-import logging
 import signal
 
 import tornado.netutil
@@ -13,7 +13,7 @@ import tornado.web
 from tornado.httpserver import HTTPServer
 from tornado.ioloop import IOLoop
 from tornado.options import define, options
-from utils import get_ip
+from utils import Logger, get_ip
 
 __all__ = ['Blueprint', 'Application']
 
@@ -80,7 +80,7 @@ class Application(Blueprint):
 
     def __init__(self, name=None, url_prefix='/', host='.*', strict_slashes=False, **kwargs):
         super().__init__(name, url_prefix, host, strict_slashes)
-        self.logger = logging
+        self.logger = Logger()
         self.kwargs = kwargs
         self.handlers = []
         self.prefix = 'web'
