@@ -9,7 +9,6 @@ import copy
 import datetime
 import hashlib
 import json
-import logging
 import math
 import re
 import time
@@ -18,14 +17,15 @@ import urllib.parse
 
 import tornado.web
 from bson import ObjectId
-from utils import Dict, JSONEncoder, Mongo, Motor, awaitable, cached_property
+from utils import (Dict, JSONEncoder, Logger, Mongo, Motor, awaitable,
+                   cached_property)
 
 
 class BaseHandler(tornado.web.RequestHandler):
 
     def __init__(self, application, request, **kwargs):
         super().__init__(application, request, **kwargs)
-        self.logger = logging
+        self.logger = Logger()
         self.ua = self.request.headers.get('User-Agent', '')
         self.referer = self.request.headers.get('Referer', '')
         self.host = self.request.headers.get('Host', self.request.host)
@@ -71,14 +71,16 @@ class BaseHandler(tornado.web.RequestHandler):
         else:
             return False
 
-    async def check_sign(self):
+    async def check_sign(self, prefix='digua', method='md5'):
+        self.args.t = self.args.t[0] if isinstance(self.args.t, list) else self.args.t
         if not (self.args.t and self.args.n and self.args.s):
             raise tornado.web.HTTPError(403)
 
         if time.time() - int(self.args.t, 16) >= 3600:
             raise tornado.web.HTTPError(403)
 
-        if self.args.s != hashlib.md5(f'digua_{self.args.t}_{self.args.n}'.encode()).hexdigest():
+        key = f'{prefix}_{self.args.t}_{self.args.n}'.encode()
+        if self.args.s[:8] != getattr(hashlib, method)(key).hexdigest()[:8]:
             raise tornado.web.HTTPError(403)
 
         '''
@@ -115,6 +117,10 @@ class BaseHandler(tornado.web.RequestHandler):
         else:
             return self.request.remote_ip
 
+    @cached_property
+    def port(self):
+        return self.request.headers.get('X-Real-Port')
+
     @cached_property
     def mobile(self):
         regexp = re.compile(r'Mobile|Android|iPhone|Windows Phone|iPad|Opera Mobi|iPod|UCBrowser|MQQBrowser|Quark|MicroMessenger', re.I)
