@@ -79,6 +79,8 @@ class BaseHandler(BaseHandler):
             return Dict({'err': 1, 'msg': '邮箱地址太长'})
         if not re.match(r'.*@(.*)\.(\w+)$', email):
             return Dict({'err': 1, 'msg': '请填写正确的邮箱格式'})
+        if not re.search(r'@(qq.com|gmail.com|163.com|126.com|yeah.net|outlook.com|live.com|foxmail.com|hotmail.com|sina.com|vip.qq.com|139.com|icloud.com|aliyun.com|88.com|sina.cn|tom.com|live.cn|yahoo.com|189.cn|msn.com|sohu.com|yandex.com|.edu.cn|vip.163.com|msn.cn)$', email.lower()):
+            return Dict({'err': 1, 'msg': '请使用常用邮箱注册'})
         if await awaitable(self.db.users.find_one({'email': email})):
             return Dict({'err': 1, 'msg': '邮箱地址重复'})
         return Dict({'err': 0})
@@ -229,7 +231,8 @@ class UserHandler(BaseHandler):
 
     async def get(self):
         if self.current_user:
-            self.finish(self.current_user)
+            user = {k: v for k, v in self.current_user.items() if k not in ['_id', 'password']}
+            self.finish(user)
         else:
             self.finish({'err': 1, 'msg': '用户未登录'})
 
