@@ -17,9 +17,10 @@ from .db_utils import (AioMysql, AioRedis, Mongo, MongoClient, Motor,
 from .decorator import aioretry, retry, smart_decorator, synchronize, timeit
 from .email_utils import AioEmail, Email
 from .fire import Fire
-from .http_utils import Chrome, Response, patch_connection_pool
+from .http_utils import Response, patch_connection_pool
 from .log_utils import Logger, WatchedFileHandler
 from .rabbitmq import AioPika, Pika
+from .stopwatch import Stopwatch
 from .xdb_searcher import XdbSearcher
 
 try:
@@ -39,5 +40,5 @@ __all__ = [
     'Fire', 'Singleton', 'JSONEncoder', 'Dict', 'DefaultDict', 'DictWrapper', 'DictUnwrapper',
     'Email', 'AioEmail', 'Config', 'Logger', 'WatchedFileHandler', 'Storage', 'XdbSearcher',
     'Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient', 'Mysql', 'AioMysql', 'Pika', 'AioPika',
-    'Request', 'Response', 'Chrome'
+    'Request', 'Response', 'Stopwatch'
 ]
