@@ -55,8 +55,6 @@ def yaml_dump(data, stream=None, default_flow_style=False, allow_unicode=True, s
 
 
 yaml.add_constructor('!include', _include_yaml)
-yaml.load = yaml_load
-yaml.dump = yaml_dump
 
 
 class tqdm(tqdm):
@@ -341,31 +339,33 @@ def int2str(int_time):
     return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(int_time))
 
 
-def pprint(docs, header=None, auto=False):
+def pprint(docs, header=None, auto=False, index=False):
     console = Console()
     if auto:
         stack = inspect.stack()
         if not [x for x in stack if x.function == 'Fire']:
             return
 
-    if isinstance(docs, (list, tuple)):
-        table = Table(show_header=True, header_style="bold magenta")
-        if header is not None:
-            for key in header:
-                table.add_column(key)
-        if isinstance(docs[0], dict):
-            if header is None:
-                header = sorted(set(reduce(lambda x, y: x + y, [list(x.keys()) for x in docs])))
-                for key in header:
-                    table.add_column(key)
-            for doc in docs:
-                table.add_row(*[str(doc.get(x, '')) for x in header])
-            console.print(table)
-        elif isinstance(docs[0], (list, tuple)):
-            for doc in docs:
-                table.add_row(*[str(x) for x in doc])
-            console.print(table)
+    if not isinstance(docs, (list, tuple)):
+        return console.print(docs)
+
+    table = Table(show_header=True, header_style="bold magenta")
+    if index:
+        table.add_column('idx')
+    if header is None and docs and isinstance(docs[0], dict):
+        header = sorted(set(reduce(lambda x, y: x + y, [list(x.keys()) for x in docs])))
+    if header is not None:
+        for key in header:
+            table.add_column(key)
+
+    for idx, doc in enumerate(docs):
+        if isinstance(doc, dict):
+            line = [str(doc.get(x, '')) for x in header]
+        elif isinstance(doc, (list, tuple)):
+            line = [str(x) for x in doc]
         else:
-            console.print(docs)
-    else:
-        console.print(docs)
+            line = [str(getattr(doc, x)) for x in header]
+        if index:
+            line.insert(0, str(idx))
+        table.add_row(*line)
+    console.print(table)
