@@ -38,10 +38,6 @@ from bs4 import BeautifulSoup
 from lxml import etree
 from requests.structures import CaseInsensitiveDict
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
-from selenium import webdriver
-from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
-from selenium.webdriver.support.ui import WebDriverWait
-from selenium.webdriver.support.wait import TimeoutException
 from tornado import httputil
 from tornado.httpclient import HTTPClient, HTTPRequest, HTTPResponse
 
@@ -439,7 +435,6 @@ class AsyncRequest(BaseRequest):
                 reason = str(e)
                 self.logger.error(f'url: {url}, retry: {i}, exception: {e}')
                 await asyncio.sleep(self.sleep)
-
         return Response(url=url, code=599, reason=reason)
 
     async def _download(self, url, kwargs, fp, lock, start, end):
@@ -618,7 +613,7 @@ class Aiohttp(AsyncRequest):
 
     def _prepare(self, url, kwargs):
         url, kwargs = super()._prepare(url, kwargs)
-        kwargs.setdefault('verify_ssl', False)
+        kwargs.setdefault('verify_ssl', kwargs.pop('verify', False))
         kwargs.setdefault('raise_for_status', True)
         kwargs.pop('progress', None)
         kwargs.pop('chunked', None)
@@ -719,80 +714,6 @@ class Fetcher(BaseRequest):
         return response
 
 
-class Chrome(webdriver.Chrome):
-
-    def __init__(self, path=None, headless=False, proxy=None, mobile=None):
-        options = webdriver.ChromeOptions()
-        options.add_experimental_option('excludeSwitches', ['enable-automation', 'ignore-certificate-errors'])
-        options.add_experimental_option('w3c', False)
-        options.add_argument('disable-infobars')
-        options.add_argument('lang=zh_CN.UTF-8')
-        options.add_argument('profile-directory=Default')
-        # options.add_extension(Path(__file__).parent / 'Adblock-Plus_v1.8.12.crx')
-        # options.add_argument('disable-gpu')
-        # options.add_argument('no-sandbox')
-        # options.add_argument(f"user-data-dir={Path('~/Library/Application Support/Google/Chrome').expanduser()}")
-        if path:
-            options.add_argument(f'user-data-dir={path}')
-        if headless:
-            options.add_argument('headless')
-        if proxy:
-            options.add_argument(f'proxy-server={proxy}')
-        if mobile == 'ios':
-            options.add_argument('user-agent="Mozilla/5.0 (iPhone; CPU iPhone OS 9_1 like Mac OS X) AppleWebKit/601.1.46 (KHTML, like Gecko) Version/9.0 Mobile/13B143 Safari/601.1"')
-        elif mobile == 'android':
-            options.add_argument('user-agent="Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.87 Mobile Safari/537.36"')
-        caps = DesiredCapabilities.CHROME
-        caps['loggingPrefs'] = {'performance': 'ALL'}
-        super().__init__(options=options, desired_capabilities=caps)
-        self.wait = WebDriverWait(self, 30)
-
-    def get(self, url):
-        super().get(url)
-        request = Dict()
-        resp = Dict()
-        for item in self.get_log('performance'):
-            message = Dict(json.loads(item['message'])).message
-            if message.method == 'Network.responseReceived' and \
-                    message.params.response.url.strip('/') == url.strip('/'):
-                resp.headers = CaseInsensitiveDict(message.params.response.headers)
-                request.headers = CaseInsensitiveDict(message.params.response.requestHeaders)
-                code = message.params.response.status
-
-        if resp.headers:
-            cookie = SimpleCookie()
-            cookie.load(request.headers.get('Cookie', ''))
-            request.cookies = dict([(x[0], x[1].value) for x in cookie.items()])
-            cookie = SimpleCookie()
-            cookie.load(resp.headers.get('Set-Cookie', ''))
-            resp.cookies = dict([(x[0], x[1].value) for x in cookie.items()])
-            return Response(url=url, request=request, code=code, body=self.page_source,
-                            headers=resp.headers, cookies=resp.cookies, reason='OK')
-
-    def find(self, selector):
-        try:
-            elements = self.wait.until(lambda driver: driver.find_elements_by_css_selector(selector))
-            return elements[0] if len(elements) == 1 else elements
-        except TimeoutException:
-            return None
-
-    def check(self, selector):
-        try:
-            WebDriverWait(self, 1).until(lambda driver: driver.find_element_by_css_selector(selector))
-            return True
-        except TimeoutException:
-            return False
-
-    def scroll(self, page=1, sleep=1):
-        for i in range(page):
-            self.execute_script('scrollTo(0, document.body.scrollHeight)')
-            if i < page - 1:
-                time.sleep(sleep)
-
-    def soup(self):
-        return BeautifulSoup(self.page_source, 'html5lib')
-
-
 def Request(lib='requests', **kwargs):
     module = {
         'requests': Requests,
